@@ -36,6 +36,8 @@
 #define swprintf _snwprintf
 #endif
 
+#include "osal_files.h"
+
 typedef struct {
     uint32 *src;
     uint32 srcwidth;
@@ -283,15 +285,15 @@ TxFilter::filter(uint8 *src, int srcwidth, int srcheight, uint16 srcformat, uint
         uint8 *_tmptex  = tmptex;
 
 #if !defined(NO_FILTER_THREAD)
-        unsigned int numcore = _numcore;
+        unsigned int numcore = (_numcore < 32) ? _numcore : 32;
         unsigned int blkrow = 0;
         while (numcore > 1 && blkrow == 0) {
           blkrow = (srcheight >> 2) / numcore;
           numcore--;
         }
         if (blkrow > 0 && numcore > 1) {
-          SDL_Thread *thrd[MAX_NUMCORE];
-          FilterParams params[MAX_NUMCORE];
+          SDL_Thread *thrd[32];
+          FilterParams params[32];
           unsigned int i;
           int blkheight = blkrow << 2;
           unsigned int srcStride = (srcwidth * blkheight) << 2;
@@ -658,18 +660,18 @@ TxFilter::dmptx(uint8 *src, int width, int height, int rowStridePixel, uint16 gf
 
     /* create directories */
     tmpbuf.assign(_datapath + L"/texture_dump");
-    if (!boost::filesystem::exists(tmpbuf) &&
-        !boost::filesystem::create_directory(tmpbuf))
+    if (!osal_path_existsW(tmpbuf.c_str()) &&
+        !osal_mkdirp(tmpbuf.c_str()))
       return 0;
 
     tmpbuf.append(L"/" + _ident);
-    if (!boost::filesystem::exists(tmpbuf) &&
-        !boost::filesystem::create_directory(tmpbuf))
+    if (!osal_path_existsW(tmpbuf.c_str()) &&
+        !osal_mkdirp(tmpbuf.c_str()))
       return 0;
 
     tmpbuf.append(L"/GlideHQ");
-    if (!boost::filesystem::exists(tmpbuf) &&
-        !boost::filesystem::create_directory(tmpbuf))
+    if (!osal_path_existsW(tmpbuf.c_str()) &&
+        !osal_mkdirp(tmpbuf.c_str()))
       return 0;
 
     if ((n64fmt >> 8) == 0x2) {
