@@ -440,7 +440,7 @@ grTexDownloadMipMap( GrChipID_t tmu,
 
     // VP fixed the texture conversions to be more accurate, also swapped
     // the for i/j loops so that is is less likely to break the memory cache
-    register int n = 0, m = 0;
+    int n = 0, m = 0;
     switch(info->format)
     {
     case GR_TEXFMT_ALPHA_8:
